

// SCENE Introduction

// scenes\Introduction\IntroductionController.js

/**
 * Controller for the Introduction scene.
 * @param {string} sceneId The id of the scene.
 */
function IntroductionController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var genderChoice = "gender";
    var nameChoice = "name";
    var sanityLower = "sanity";
    var pressedContinue = "continue";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets the kobold's gender to the selected one.
     * @param {GenderEnum} choice The selected gender.
     */
    function genderChoiceGender(choice) {
        global.kobold.body.setGender(choice);
        if (choice == GenderEnum.MALE) {
            global.kobold.body.growDick(SizeEnum.SMALL);
        }
        if (choice == GenderEnum.FEMALE) {
            global.kobold.body.growBreasts(SizeEnum.SMALL);
        }
    }

    /**
     * Adds stats to the kobold depending on the chosen gender.
     * @param {GenderEnum} choice The selected gender.
     */
    function genderChoiceStats(choice) {
        if (choice == GenderEnum.MALE) {
            global.kobold.stats.increaseStat(StatsEnum.STRENGTH, 1);
            global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
        }
        if (choice == GenderEnum.FEMALE) {
            global.kobold.stats.increaseStat(StatsEnum.AGILITY, 1);
            global.kobold.stats.increaseStat(StatsEnum.CHARISMA, 1);
        }
    }

    /**
     * Adds equipment to the kobold depending on the chosen gender.
     * @param {GenderEnum} choice The selected gender.
     */
    function genderChoiceEquipment(choice) {
        if (choice == GenderEnum.MALE) {
            global.kobold.inventory.equipment.wear(new LoinCloth());
        }
        if (choice == GenderEnum.FEMALE) {
            global.kobold.inventory.equipment.wear(new LinenPants());
            global.kobold.inventory.equipment.wear(new ChestWrap());
        }
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Makes the gender choice, setting the kobold's gender and altering the kobold's history.
     * @param {GenderEnum} choice The selected gender.
     */
    this.makeGenderChoice = function (choice) {
        var history = global.kobold.history.get(id);
        history[genderChoice] = choice;
        global.kobold.history.set(id, history);
        genderChoiceGender(choice);
        genderChoiceStats(choice);
        genderChoiceEquipment(choice);
    };

    /**
     * Fetches the gender choice from history and returns it.
     * May return undefined if the choice has not yet been made.
     */
    this.getGenderChoice = function () {
        var history = global.kobold.history.get(id);
        return history[genderChoice];
    };

    /**
     * Returns true if the gender choice has already been made. False otherwise.
     */
    this.hasMadeGenderChoice = function () {
        return global.kobold.history.has(id, genderChoice);
    };

    /**
     * Makes the name choice, setting the kobold's name.
     * @param {string} name The entered name.
     */
    this.makeNameChoice = function (name) {
        var history = global.kobold.history.get(id);
        history[nameChoice] = name;
        global.kobold.history.set(id, history);
        global.kobold.name = name;
    };

    /**
     * Fetches the name choice from history and returns it.
     * May return undefined if the choice has not yet been made.
     */
    this.getNameChoice = function () {
        var history = global.kobold.history.get(id);
        return history[nameChoice];
    };

    /**
     * Returns true if the name choice has already been made. False otherwise.
     */
    this.hasMadeNameChoice = function () {
        return global.kobold.history.has(id, nameChoice);
    };
    
    /**
     * Presses the continue button.
     */
    this.pressContinue = function () {
        var history = global.kobold.history.get(id);
        history[pressedContinue] = true;
        global.kobold.history.set(id, history);
    };
    
    /**
     * Returns true if the continue button has been pressed.
     */
    this.hasContinued = function () {
        return global.kobold.history.has(id, pressedContinue);
    };

    /**
     * Lowers the kobold's sanity, if it hasn't been lowered yet.
     * @returns {string} HTML describing the change.
     */
    this.thirdPartMentalEffects = function () {
        if (!global.kobold.history.has(id, sanityLower)) {
            global.kobold.status.mental.decrease(15, "Deadline worries");
            var history = global.kobold.history.get(id);
            history[sanityLower] = true;
            global.kobold.history.set(id, history);
        }
        return global.ui.change.buildNotification([new Change("Distraught", "Sanity", -15)]);
    };
}

// END scenes\Introduction\IntroductionController.js

// scenes\Introduction\IntroductionFirstPart.js

/**
 * The first part of the introduction.
 * @param {IntroductionController} controller The controller.
 * @param {IntroductionSecondPart} secondPart The next part to load once finished.
 */
function IntroductionFirstPart(controller, secondPart) {
    // PRIVATE MEMBERS \\       var private = "test";
    var ctrl = controller;
    var nextPart = secondPart;
    var start =  `  <div class="title fancy">
                         introduction
                    </div>
                    <div class="text">
                        You are a <span class="bold">kobold</span>. You are small, flexible, nimble and rather stealthy when you want
                        to be. On the other hand you are naive, not very strong, kind of a pushover and 
                        generally not very good in a fight. You make up for your lack of combat skills
                        by a driven determination not to fall prey to the many dangers of this world.
                    </div>

                    <div class="text">
                        The area you live in is mostly predominated by humans and anthros, who see you as a lesser species. 
                        Kobolds officially have no rights, so the sight of one of your kind getting raped, 
                        beaten, sold as a slave or even killed in broad daylight is, unfortunately for you, not so uncommon.
                    </div>

                    <div class="text">
                        Luckily, you have managed to avoid the worst so far, by making your home in the outstretched 
                        woods surrounding the human capital of <span class="bold">Varanar</span>. While the city itself is 
                        a melting pot for all walks of life, the forest isn't nearly as diverse.
                    </div>
    
                    <div class="text">
                        Still, there's plenty to be afraid of. 
                        Wolves, bobcats, forest wyverns, gryphons, you name it.
                        Heck, even something as docile as a deer, when provoked, could pose a threat to a small kobold like you.
                        To make matters worse, there are rumors going around of a hulking mass of tentacles skulking through the darkness, 
                        violating who or <span class="italic">what</span>ever it gets in its grip.
                    </div>

                    <div class="text">
                        On top of the feral dangers, there are various bandits and outlaws 
                        which have made these woods their home. Many of them band together, forming
                        fickle alliances that often end in backstabbing and betrayal, all in pursuit
                        of coin. They prey on unsuspecting victims, to rob them of their 
                        riches, their decency, their life or all three.
                    </div>
    
                    <div class="text">
                        Some of these groups are comprised exclusively of kobolds.
                        One of them is the <span class="bold">Three-Tailed Rat Clan</span>.
                        Based in Varanar, this organized gang of ruthless, thick-scaled thugs is lead by 
                        the only non-kobold member, a man known as <span class="bold">The Rat</span>.
                        Their main source of income is extortion, coercing protection money from people
                        living in the more lawless regions of the land.
                        <span class="bold">Regions like the forest. And people like you.</span>
                    </div>`;
    
    var genderChoiceHeader =       `<div class="choicecontainer">
                                        <div class="inlinechoiceheader">
                                            You are:
                                        </div>`;
    
    var genderChoiceButtonMid =        `<hr class="inlinechoiceseparator">`;
    
    var genderChoiceFooter =    `</div>`;
    
    var genderChoiceButtonMaleId = "male";
    var genderChoiceButtonFemaleId = "female";
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    
     /**
     * Builds and returns the gender choice.
     * The starting choice may be disabled if it has already been made.
     */
    function buildGenderChoice() {
        var choice = genderChoiceHeader;
        choice += buildGenderChoiceMaleButton();
        choice += genderChoiceButtonMid;
        choice += buildGenderChoiceFemaleButton();
        choice += genderChoiceFooter;
        return choice;
    }
    
    /**
     * Returns the male choice button.
     */
    function buildGenderChoiceMaleButton() {
        var disabled = ctrl.hasMadeGenderChoice() ? "disabled" : "";
        var selected = ctrl.hasMadeGenderChoice() && ctrl.getGenderChoice() == GenderEnum.MALE ? "selected" : "";
        return `<button class="button inlinechoice ${selected}" id="${genderChoiceButtonMaleId}" ${disabled}>
                    Male
                </button>`;
    }
    
    /**
     * Returns the female choice button.
     */
    function buildGenderChoiceFemaleButton() {
        var disabled = ctrl.hasMadeGenderChoice() ? "disabled" : "";
        var selected = ctrl.hasMadeGenderChoice() && ctrl.getGenderChoice() == GenderEnum.FEMALE ? "selected" : "";
        return `<button class="button inlinechoice ${selected}" id="${genderChoiceButtonFemaleId}" ${disabled}>
                    Female
                </button>`;
    }
        
    /**
     * Registers a click listener for the male gender choice button.
     */
    function registerMaleGenderChoiceListener() {
        $("#" + genderChoiceButtonMaleId).click(function(){
            $(this).addClass("selected");
            genderChoiceClick(GenderEnum.MALE);
        });
    }
    
    /**
     * Registers a click listener for the female gender choice button.
     */
    function registerFemaleGenderChoiceListener() {
        $("#" + genderChoiceButtonFemaleId).click(function(){
            $(this).addClass("selected");
            genderChoiceClick(GenderEnum.FEMALE);
        });
    }
    
    /**
     * Executed when a gender choice button is clicked.
     * @param {GenderEnum} choice The selected gender.
     */
    function genderChoiceClick(choice) {
        disableButtons();
        ctrl.makeGenderChoice(choice);
        var secondPart = nextPart.build(true);
        global.ui.appendBeforeFinisher(secondPart, global.ui.genericHeaderId);
        $("#" + nextPart.id).fadeIn(400);
        nextPart.registerListeners();
    }
    
    /**
     * Disables both gender choice buttons.
     */
    function disableButtons() {
        var maleButton = $("#" + genderChoiceButtonMaleId);
        var femaleButton = $("#" + genderChoiceButtonFemaleId);
        maleButton.unbind();
        femaleButton.unbind();
        maleButton.prop('disabled', true);
        femaleButton.prop('disabled', true);
    }
    
    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Builds and returns this part.
     */
    this.build = function() {
        return start + buildGenderChoice();
    };
    
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function() {
        if(ctrl.hasMadeGenderChoice()){
            return;
        }
        registerMaleGenderChoiceListener();
        registerFemaleGenderChoiceListener();
    };
}

// END scenes\Introduction\IntroductionFirstPart.js

// scenes\Introduction\IntroductionSecondPart.js

/**
 * The second part of the introduction.
 * @param {IntroductionController} controller The controller.
 * @param {IntroductionThirdPart} thirdPart The next part to load once finished.
 */
function IntroductionSecondPart(controller, thirdPart) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var nextPart = thirdPart;
    var nameInputId = "namefield";
    var submitNameButtonId = "namebutton";

    var maleDescription = `<div class="text">
                                You are male. You're a bit stronger and tougher than the females of your kind, 
                                yet still pathetically weak compared to anything that isn't a kobold. 
                                You’re wearing nothing but a small, simple ${global.kobold.inventory.createItemWithTooltip(new LoinCloth())}, 
                                which covers the cockslit between your legs quite nice. Your scaly butt, 
                                however, is completely exposed. The only thing covering your virginal rear is your tail.
                            </div>`;

    var femaleDescription = `<div class="text">
                                You are female. You’re not quite as strong as the males of your kind, but you make 
                                up for it by being even lighter, even more nimble and just a little bit more flexible. 
                                Enemies you face might be more concerned with fucking something as small and cute as 
                                yourself rather than trying to hurt you. This may be a good thing, yet if you don’t 
                                watch out you might end up a cum-filled lizard before long. 
                            </div>
                            <div class="text">
                                You wear a baggy pair of brown ${global.kobold.inventory.createItemWithTooltip(new LinenPants())}, 
                                and a matching ${global.kobold.inventory.createItemWithTooltip(new ChestWrap())} which covers up
                                your small breasts quite nicely. Your leg-wear has seen better days. Small holes and
                                cuts dot the fabric in every which way, some large enough to show just a glimmer of your
                                scales beneath. At least your groin and rear are still suitably covered.
                            </div>`;

    var postDescription = `<div class="text">
                                <span class="sneakytext bold">
                                    You can check your attributes in the stats tab, as well as get a physical description of your body.
                                    Your equipment can be found in the inventory tab.
                                    The names of most pieces of equipment can be moused over to reveal a short description of the item.
                                    Your current health, sanity, stamina and sexual exertion may be viewed in the status tab.
                                </span>
                            </div>
                            <div class="text">
                                You used to have a comfortable wool sweater that had kept you warm for many winters, 
                                yet you lost it just a few days ago whilst running from a rather unpleasant group of humans.
                                The soft fabric got caught on a thornbush. Fearing for your life, you slipped out of the 
                                sweater instead of trying to pry it loose. You can't quite remember where all of this happened.
                                The forest can be a confusing place, at times.
                            </div>
                            `;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the enclosing div's starting tag.
     * @param {bool} invisible True if the entire section should be invisible.
     * @returns {string} The starting tag.
     */
    function enclosingDivStart(invisible) {
        var style = invisible ? 'style="display:none;"' : "";
        return `<div id="${that.id}" ${style} >`;
    }

    /**
     * Builds and returns the gender-specific description part.
     * @returns {string} The gender-specific description part.
     */
    function genderDescription() {
        if (ctrl.getGenderChoice() == GenderEnum.MALE) {
            return maleDescription;
        } else {
            return femaleDescription;
        }
    }

    /**
     * Builds and returns the end of the enclosing division.
     * @returns {string} The end of the enclosing division.
     */
    function enclosingDivEnd() {
        return "</div>";
    }

    /**
     * Builds and returns the name selection section.
     * @returns {string} The name selection section.
     */
    function nameSelection() {
        var nameChoiceMade = ctrl.hasMadeNameChoice();
        var disabled = nameChoiceMade ? "disabled" : "";
        var value = nameChoiceMade ? ctrl.getNameChoice() : "Moe";
        var nameSelect = `<div class="choicecontainer">`;
        nameSelect += `<div class="inlinechoiceheader">Your name is:</div>`;
        nameSelect += `<input id="${nameInputId}" class="textinput" maxlength="20" value="${value}" ${disabled}>`;
        nameSelect += `<button id="${submitNameButtonId}" class="button textinputbutton" ${disabled}>Confirm</button>`;
        nameSelect += `</div>`;
        return nameSelect;
    }

    /**
     * Registers a listener disabling the name submit button if no name has been entered.
     */
    function registerNameInputChangeListener() {
        var input = $("#" + nameInputId);
        var button = $("#" + submitNameButtonId);
        input.on('input', function () {
            var value = input.val();
            if (value.length === 0) {
                button.prop('disabled', true);
            } else {
                button.prop('disabled', false);
            }
        });
    }

    /**
     * Registers a listener capable of submitting the name choice.
     */
    function registerNameSubmitListener() {
        var input = $("#" + nameInputId);
        var button = $("#" + submitNameButtonId);
        button.click(function () {
            var value = input.val();
            if (value.length === 0) {
                return;
            }
            button.prop('disabled', true);
            input.prop('disabled', true);
            ctrl.makeNameChoice(value);
            var thirdPart = nextPart.build(true);
            global.ui.appendBeforeFinisher(thirdPart, global.ui.genericHeaderId);
            $("#" + nextPart.id).fadeIn(400);
            nextPart.registerListeners();
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "part2";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.hasMadeGenderChoice()) {
            return "";
        }
        var part = enclosingDivStart(invisible);
        part += genderDescription();
        part += postDescription;
        part += nameSelection();
        part += enclosingDivEnd();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.hasMadeGenderChoice()) {
            return;
        }
        if (ctrl.hasMadeNameChoice()) {
            return;
        }
        registerNameInputChangeListener();
        registerNameSubmitListener();
    };
}

// END scenes\Introduction\IntroductionSecondPart.js

// scenes\Introduction\IntroductionThirdPart.js

/**
 * The third part of the introduction.
 * @param {IntroductionController} controller The controller.
 */
function IntroductionThirdPart(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    var nextScene = "Forest";

    var continueButtonId = "continueButton";
    var contentStart = `<div class="text">`;
    var contentMiddle = `   You are a thief. You make a living by sneaking into the
                            various camps of passersby, bandits and other forest-inhabitants,
                            stealing whatever you can and then hightailing it out of there hoping you weren't seen.
                            This tactic has worked out pretty well for you in the past.
                            For several years, you've managed to stay afloat, if just barely.
                            Some months you even had the money to buy yourself some actual food, 
                            instead of living off the scraps of others.
                        </div>
                        <div class="text">
                            Those golden days are over.
                            The Three-Tailed Rat Clan has recently raised its <span class="italic">fee</span>
                            to a level you can no longer afford. 
                            Fifty coins per month was a reasonable tariff, but one hundred is simply
                            <span class="bold">too</span> much for a simple kobold like yourself to steal on a monthly basis.
                            You have no choice <span class="bold">but</span> to pay, however. 
                            You have nowhere else to go, you've grown rather attached to your little shack in the woods,
                            and you'd rather <span class="bold">not</span> risk the ire of one of the deadliest gangs around.
                        </div>
                        <div class="text">
                            Over the past few months, you've been working your <span class="bold">ass</span> off trying to make ends meet.
                            You've been taking risks: stealing from caravans, stalking bandits to pick their prey clean of any leftover coin,
                            even making a trip to the city to try your hand at pickpocketing. 
                            Despite your best attempts, you've accumulated a significant amount of debt.
                            <span class="bold">Two hundred and fifty</span> coins worth, to be precise.
                        </div>
                        <div class="text">
                            The Three-Tailed Rat himself has issued you a warning.
                            Of course, not in person. 
                            Nobody talks to the Rat but his second-in-command.
                            A courier delivered a letter to your very doorstep.
                            Three days. 
                            That's all the time you had to repay your debt.
                            <span class="bold">Or else.</span>
                        </div>`;

    var contentMiddle2 = `  <div class="text">
                            Needless to say, the worries clouding your mind haven't been very conducive to your trade.
                            In fact, you've fumbled every single heist you've attempted since receiving the note.
                            Worse yet, last night, you were unfortunate enough to drop your meagre coin pouch while running from a pair of mounted caravan guards.
                            Today, the last day you had to pay up, you spent scouring every inch of the forest floor in a desperate attempt to recover your purse.
                        </div>
                        <div class="text">
                            The few coins within might have been enough to at least buy you some time, but alas.
                            The horsemen must have taken it as their just due. 
                            Or maybe another group stumbled upon it. 
                            Heck, the neck cord could have wrapped itself around some wild animal's leg for all you know.
                        </div>
                        <div class="text">
                            In the early afternoon, you were about ready to give up.
                            Not just on finding your lost pouch, but on <span class="bold">everything</span>.
                            You were done for.
                            A quarter of a thousand gold due tonight, and you hadn't a coin to your name.
                            All seemed lost.
                        </div>
                        <div class="text">
                            Still, a flicker of hope remained.
                            At least you didn't get caught by the horsemen. `;

    var contentEnd = `   Maybe, just maybe, you could meet your deadline still.
                            You just needed to score <span class="bold">one big hit.</span>
                            Driven by the will to live, you set out to do what you do best.
                        </div>`;


    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the first section of the third part.
     * @returns {string} The first section of the third part.
     */
    function buildName() {
        var gender = ctrl.getGenderChoice();
        var name = ctrl.getNameChoice();
        var part = contentStart;
        part += `Your name is <span class="bold">${name}</span>. `;
        part += contentMiddle;
        part += contentMiddle2;
        if (gender == GenderEnum.MALE) {
            part += `And the way you escaped them by <span class="bold">climbing up a tree</span> was pretty darn impressive.`;
        } else {
            part += `And the way you escaped them by <span class="bold">hiding in a bush</span> was pretty darn impressive.`;
        }

        part += contentEnd;
        return part;
    }

    /**
     * Builds and returns the continue button at the end of the scene.
     * @returns {string} The continue button.
     */
    function buildContinueButton() {
        var disabled = ctrl.hasContinued();
        var button = `<button class="button bigbutton continuebutton" id="${continueButtonId}" ${disabled ? "disabled" : ""}>`;
        button += `Continue &gt;&gt`;
        button += `</button>`;
        return button;
    }

    /**
     * Registers a listener for the continue button.
     */
    function registerContinueButtonListener() {
        $("#" + continueButtonId).click(function () {
            ctrl.pressContinue();
            global.ui.fadeOutContent(function () {
                global.sceneEnd();
                global.sceneLoader.loadScene(nextScene);
            });
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "part3";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {bool} invisible True if the entire section should be invisible.
     */
    this.build = function (invisible) {
        if (!ctrl.hasMadeNameChoice()) {
            return "";
        }
        
        var change = ctrl.thirdPartMentalEffects();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildName(change);
        part += change;
        part += buildContinueButton();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.hasContinued()) {
            return;
        }
        registerContinueButtonListener();
    };
}

// END scenes\Introduction\IntroductionThirdPart.js

// scenes\Introduction\IntroductionBuilder.js

/**
 * Builder for the Introduction scene.
 * @param {IntroductionController} controller The controller managing this scene.
 */
function IntroductionBuilder(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var thirdPart = new IntroductionThirdPart(controller);
    var secondPart = new IntroductionSecondPart(controller, thirdPart);
    var firstPart = new IntroductionFirstPart(controller, secondPart);
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Progressively builds the contents of the scene.
     * @returns {string} The innards of the scene, as a HTML string.
     */
    this.buildScene = function() {
        var scene = firstPart.build();
        scene += secondPart.build();
        scene += thirdPart.build();
        return scene;
    };
    
    /**
     * Registers all the required button listeners.
     */
    this.registerListeners = function() {
        firstPart.registerListeners();
        secondPart.registerListeners();
        thirdPart.registerListeners();
    };
}

// END scenes\Introduction\IntroductionBuilder.js

// scenes\Introduction\Introduction.js

/**
 * The Introduction scene. Shown after the big button in the title screen has been clicked.
 */
function Introduction() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "Introduction";
    var sceneName = "Introduction";
    var controller = new IntroductionController(sceneId);
    var builder = new IntroductionBuilder(controller);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += builder.buildScene();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        var audio = new AudioController(that.id, "res/audio/titlescreen/guitar_chord.mp3", 100);
        audio.playOnce();
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
        global.ui.applyTheme();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        builder.registerListeners();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new Introduction();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Introduction\Introduction.js



// END SCENE Introduction

